#
# "This sample program is provided AS IS and may be used, executed, copied and modified without royalty payment by customer(a) for its own 
# instruction and study, (b) in order to develop applications designed to run with an IBM WebSphere product, either for customer's own internal use 
# or for redistribution by customer, as part of such an application, in customer's own products."
#
#  @start_restricted_prolog@
#
#    Licensed Materials - Property of IBM
#    5724-I82 5724-L01 5655-N53 5655-R15            
#    Copyright IBM Corporation 2005, 2009 All Rights Reserved.
#    US Government Users Restricted Rights- Use, duplication or disclosure
#    restricted by GSA ADP Schedule Contract with IBM Corp.
#    
#  @end_restricted_prolog@
#

print "\n ***** Running MQDataBindingJNDIResources.py ***** \n"

def createMQConnectionFactory(cfName, jndiName, qmName, hostname, port, channel):
	"Create the specified MQ connection factory"
	print "\n ***** Creating MQ Connection Factory ***** \n"
	# Create a list of the current MQ Connection Factory
	cfNames = []
	for cf in AdminConfig.list("MQConnectionFactory").split():
		cfNames.append(AdminConfig.showAttribute(cf, "name"))
	# Check if the connection factory has already been created
	if not cfName in cfNames:
		print "\tCreate new MQ Connection Factory " + cfName
		name = ['name', cfName]
		jndiName = ['jndiName', jndiName]
		description = ['description', "MQ Data Binding Sample Connnection Factory " + cfName]
		channel = ['channel', channel]
		host = ['host', hostname]
		queueManager = ['queueManager', qmName]
		port = ['port', port]
		transportType = ['transportType', 'CLIENT']
		provider = AdminConfig.getid('/Cell:' + AdminControl.getCell() + '/Node:' + AdminControl.getNode() + '/JMSProvider:WebSphere MQ JMS Provider/')
		params = [name, jndiName, description, channel, host, queueManager, port, transportType]
		resource = AdminConfig.create('MQConnectionFactory', provider, params)
		AdminConfig.create('ConnectionPool', resource, [], 'connectionPool')
	else:
		print "\tMQ Connection Factory " + cfName + " already exist."
	return
	
def addCustomProperties(resource):
	"Add the required MQ flags to the MQ Queue"
	print "\n ***** Adding custom properties ***** \n"
	propertySet = AdminConfig.showAttribute(resource, 'propertySet')
	if propertySet == None:
		propertySet = AdminConfig.create('J2EEResourcePropertySet', resource, "")
	AdminConfig.create('J2EEResourceProperty', propertySet, [['name', 'MDWRITE'], ['value', 'YES']])
	AdminConfig.create('J2EEResourceProperty', propertySet, [['name', 'MDREAD'], ['value', 'YES']])
	AdminConfig.create('J2EEResourceProperty', propertySet, [['name', 'MSGBODY'], ['value', 'MQ']])
	return
	
def createQueue(name, jndiName, qName):
	"Create the specified MQ Queue"
	print "\n ***** Creating queue ***** \n"
	scope = AdminConfig.getid('/Cell:' + AdminControl.getCell() + '/Node:' + AdminControl.getNode())
	queueNames = []
	for queue in AdminConfig.list('MQQueue').split():
		queueNames.append(AdminConfig.showAttribute(queue, 'name'))
	if not name in queueNames:
		print "\tCreating new queue " + name
		name = ['name', name]
		jndiName = ['jndiName', jndiName]
		description = ['description', "MQ Data Binding Sample Queue"]
		baseQueueName = ['baseQueueName', qName]
		targetClient = ['targetClient', 'MQ']
		provider = AdminConfig.getid('/Cell:' + AdminControl.getCell() + '/Node:' + AdminControl.getNode() + '/JMSProvider:WebSphere MQ JMS Provider/')
		params = [name, jndiName, description, baseQueueName, targetClient]
		resource = AdminConfig.create('MQQueue', provider, params)
		addCustomProperties(resource)
	else:
		print "\tMQ Queue " + name + " already exist."
	return
	
def createJNDIResources(mqhost, mqport, qmname, request_input_q, request_output_q, response_input_q, response_output_q):
	"Create all the JNDI resources required by the MQ Data Binding Sample"
	createMQConnectionFactory("MQDataBindingSample_Export_CF", "MQDataBindingSample_Export_CF", qmname, mqhost, mqport, "SYSTEM.DEF.SVRCONN")
	createMQConnectionFactory("MQDataBindingSample_Import_CF", "MQDataBindingSample_Import_CF", qmname, mqhost, mqport, "SYSTEM.DEF.SVRCONN")

	createQueue("MQDataBindingSample_REQUEST_INPUT_Q", "MQDataBindingSample_REQUEST_INPUT_Q", request_input_q)
	createQueue("MQDataBindingSample_REQUEST_OUTPUT_Q", "MQDataBindingSample_REQUEST_OUTPUT_Q", request_output_q)
	createQueue("MQDataBindingSample_RESPONSE_INPUT_Q", "MQDataBindingSample_RESPONSE_INPUT_Q", response_input_q)
	createQueue("MQDataBindingSample_RESPONSE_OUTPUT_Q", "MQDataBindingSample_RESPONSE_OUTPUT_Q", response_output_q)
	return
	
def deleteJNDIResources():
	"Remove all the JNDI resources used by the MQ Data Binding Sample"
	print "\n ***** Deleting JNDI resources ***** \n"
	MQConnectionFactories = ["MQDataBindingSample_Export_CF", "MQDataBindingSample_Import_CF"]
	MQQueues = ["MQDataBindingSample_REQUEST_INPUT_Q", "MQDataBindingSample_REQUEST_OUTPUT_Q", "MQDataBindingSample_RESPONSE_INPUT_Q", "MQDataBindingSample_RESPONSE_OUTPUT_Q"]
	for cf in AdminConfig.list('MQConnectionFactory').split():
		if AdminConfig.showAttribute(cf, 'name') in MQConnectionFactories:
			print "\tDeleting MQ Connection Factory " + AdminConfig.showAttribute(cf, 'name')
			AdminConfig.remove(cf)
	for queue in AdminConfig.list('MQQueue').split():
		if AdminConfig.showAttribute(queue, 'name') in MQQueues:
			print "\tDeleting MQ Queue " + AdminConfig.showAttribute(queue, 'name')
			AdminConfig.remove(queue)
	return 
	
def printValidParameters():
	"Print detail of the valid parameters."
	print "\nValid parameters are (one marked with (*) must be specified):\n"
	print "\t    -mqhost            hostname           MQ server host name (default localhost)"
	print "\t    -mqport            port_number        MQ listener port number (default 1414)"
	print "\t(*) -qmname            queue_manager_name MQ queue manager name"
	print "\t(*) -request_input_q   queue_name         Request input queue name"
	print "\t(*) -request_output_q  queue_name         Request output queue name"
	print "\t(*) -response_input_q  queue_name         Response input queue name"
	print "\t(*) -response_output_q queue_name         Response output queue name"
	print "\t    -clean                                Remove MQ Data Binding Sample JNDI resourses\n"
	return
	
VALID_OPTIONS = ["-mqhost", "-mqport", "-qmname", "-request_input_q", "-request_output_q", "-response_input_q", "-response_output_q", "-clean"]
mqhost = "localhost"   # default MQ server hostname
mqport = "1414"        # default MQ listener port number
qmname = ""            # queue manager name
request_input_q = ""   # request input queue name
request_output_q = ""  # request output queue name
response_input_q = ""  # response input queue name
response_output_q = "" # response ouptut queue name
clean = 0              # default false, the clean option has not been specified
invalid_parameters = 0 # default false, no invalid parameter has been specified

# Check all the arguments
i = 0 # start with the first one
while i < len(sys.argv):
	arg = sys.argv[i]
	if not arg in VALID_OPTIONS:
		print "\n" + arg + " is not a valid parameter.\n"
		invalid_parameters = 1 # true
	else:
		if arg == "-mqhost":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				mqhost = sys.argv[i]
			else:
				print "\tThe mqhost is not specified."
		if arg == "-mqport":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				mqport = sys.argv[i]
			else:
				print "\tThe mqport is not specified."
		if arg == "-qmname":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				qmname = sys.argv[i]
			else:
				print "\tThe qmname is not specified."
		if arg == "-request_input_q":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				request_input_q = sys.argv[i]
			else:
				print "\tThe request_input_q is not specified."
		if arg == "-request_output_q":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				request_output_q = sys.argv[i]
			else:
				print "\tThe request_output_q is not specified."
		if arg == "-response_input_q":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				response_input_q = sys.argv[i]
			else:
				print "\tThe response_input_q is not specified."
		if arg == "-response_output_q":
			i += 1
			if i != len(sys.argv) and not sys.argv[i] in VALID_OPTIONS:
				response_output_q = sys.argv[i]
			else:
				print "\tThe response_output_q is not specified."
		if arg == "-clean":
			clean = 1 # true
	i += 1

if qmname == "":
	print "\nMissing qmname parameter.\n"
	invalid_parameters = 1 # true
if request_input_q == "":
	print "\nMissing request_input_q parameter.\n"
	invalid_parameters = 1 # true
if request_output_q == "":
	print "\nMissing request_output_q paramter.\n"
	invalid_parameters = 1 # true
if response_input_q == "":
	print "\nMissing response_input_q parameter.\n"
	invalid_parameters = 1 # true
if response_output_q == "":
	print "\nMissing response_output_q parameter.\n"
	invalid_parameters = 1 # true
	
if invalid_parameters:
	printValidParameters()
elif clean:
	deleteJNDIResources()
else:
	createJNDIResources(mqhost, mqport, qmname, request_input_q, request_output_q, response_input_q, response_output_q)
AdminConfig.save()